@@ -24,7 +24,7 @@ by changing C<use Set::Object> to C<use Set::Object::Weak>.
 =cut
 
 package Set::Object::Weak;
-
+use strict;
 use base qw(Set::Object);  # boo hiss no moose::role yet I hear you say
 
 use base qw(Exporter);     # my users would hate me otherwise
@@ -82,7 +82,7 @@ add the passed members into it.
 sub set {
     my $class = __PACKAGE__;
     if (blessed $_[0] and $_[0]->isa("Set::Object")) {
-    	$class = "Set::Object";
+    	$class = (shift)->strong_pkg;
     }
     $class->new(@_);
 }
